Parser

Struct Parser 

pub struct Parser { /* private fields */ }
Parser

Implementations

Source

impl Parser

pub fn new(input: impl Into<ArcStr>) -> Self

Creates a new parser

pub const fn input(&self) -> &ArcStr

Returns the whole input of the parser

pub fn remaining(&self) -> &str

Returns the remaining string for the parser

pub const fn cur_pos(&mut self) -> AstPos

Returns the current position of the parser

pub const fn set_pos(&mut self, pos: AstPos)

Sets the position of this parser

pub fn reverse_whitespace(&mut self)

Reverses all whitespace (except the last) in the current position

pub fn reverse_line(&mut self)

Reverses to the start of the current line

pub fn cur_line(&self) -> &str

Returns the current line of the parser, not including the end

pub fn loc(&self, pos: AstPos) -> ParserLoc

Gets the position (0-indexed) of the parser at a position

pub fn cur_loc(&self) -> ParserLoc

Gets the current position (0-indexed) of the parser

pub fn is_finished(&self) -> bool

Returns if the parser is finished

pub fn update_with<F, O>(&mut self, f: F) -> (AstStr, O)
where F: FnOnce(&mut &str) -> O,

Updates this parser from a string.

See Self::try_update_with for more details.

pub fn try_update_with<F, T>( &mut self, f: F, ) -> <T::Residual as Residual<(AstStr, T::Output)>>::TryType
where F: FnOnce(&mut &str) -> T, T: Try<Residual: Residual<(AstStr, T::Output)>>,

Updates this parser from a string.

The function f receives a string to update. The value it is updated with must be a substring of the received function.

Success

When f returns successfully, the parser is updated from the state of the string.

Failure

If f returns unsuccessfully, an error will be returned with the latest change to the string as it’s position.

pub fn parse<T: Parse>(&mut self) -> Result<T, ParserError<T>>

Parses T from this parser

pub fn parse_with_peeked<T: ParsePeeked<U>, U>( &mut self, parsed: U, ) -> Result<T, ParserError<T>>

Parses T from this parser with a peeked value

pub fn try_parse_with<T, E: ParseError>( &mut self, parser: impl FnOnce(&mut Self) -> Result<T, E>, ) -> Result<Result<T, E>, E>

Tries to parses T from this parser using parser for parsing.

On error, nothing is modified.

pub fn try_parse<T: Parse>( &mut self, ) -> Result<Result<T, ParserError<T>>, ParserError<T>>

Tries to parses T from this parser.

On error, nothing is modified.

pub fn peek_with<T, E: ParseError>( &mut self, parse: impl FnOnce(&mut Self) -> Result<T, E>, ) -> Result<Result<(T, PeekState), E>, E>

Peeks a T from this parser using parser for parsing.

Parser is only advanced is a fatal error occurs

pub fn peek<T: Parse>( &mut self, ) -> Result<Result<(T, PeekState), ParserError<T>>, ParserError<T>>

Peeks a T from this parser.

Parser is only advanced is a fatal error occurs

pub const fn set_peeked(&mut self, peek_state: PeekState)

Accepts a peeked state.

pub fn tags(&self) -> impl Iterator<Item = ParserTag>

Returns all current tags

pub fn has_tag(&self, tag: impl Into<ParserTag>) -> bool

Returns if this parser has a tag

pub fn with_tags<O>( &mut self, tags: impl IntoIterator<Item = ParserTag>, f: impl FnOnce(&mut Self) -> O, ) -> O

Calls f with tags tags added to this parser

pub fn with_tag<O>( &mut self, tag: impl Into<ParserTag>, f: impl FnOnce(&mut Self) -> O, ) -> O

Calls f with tag tag added to this parser

pub fn without_tags<O>(&mut self, f: impl FnOnce(&mut Self) -> O) -> O

Calls f with all tags removed.